@@ -1,8 +1,10 @@
 #include "crondata.ih"
 
-set<size_t> CronData::assign()
+    // by sethours.cc, setdayofmonth.cc, assign2.cc, setminutes.cc
+
+CronData::SizeSet CronData::assign()
 {
-    set<size_t> dest;
+    SizeSet dest;
 
     if (d_wip.size())
     {
