@@ -1,6 +1,8 @@
 #include "crondata.ih"
 
-set<size_t> CronData::assign(char const *const *names, bool allowEnd)
+    // by setmonthofyear.cc, setdayofweek.cc
+
+CronData::SizeSet CronData::assign(char const *const *names, bool allowEnd)
 {
     size_t size = d_entryEnd - d_entryBegin;
 
