@@ -1,6 +1,8 @@
 #include "cronentry.ih"
 
-void CronEntry::showSet(ostream &out, set<size_t> const &nrSet)
+    // by insert.cc
+
+void CronEntry::showSet(ostream &out, SizeSet const &nrSet)
 {
     if (nrSet.find(STAR) != nrSet.end())
     {
