@@ -1,5 +1,7 @@
 #include "options.ih"
 
+    // by options1.cc
+
 void Options::checkAction() const
 {
             // only one of these options may be specified
@@ -18,21 +20,21 @@ void Options::checkAction() const
             fmsg << " --terminate";
         
         if (d_foreground)
-            fmsg << " --no-daemon";
+            fmsg << " --foreground";
 
-        fmsg << endl;
+        fmsg << noid;
     }
 
         // if no argument then --list or --terminate are required
     if (d_arg.nArgs() == 0)
     {
         if (not (d_list || d_terminate))
-            fmsg << "crontab file required" << endl;
+            fmsg << "crontab file required" << noid;
     }
     else if (d_list || d_terminate)
         // --list and --terminate cannot accept a crontab file
         fmsg << "crontab file incompatible with --list and --terminate" <<
-                                                                        endl;
+                                                                        noid;
 }
 
 
