@@ -1,12 +1,14 @@
 #include "options.ih"
 
+    // by options1.cc
+
 void Options::loadConfigFile()
 {
-    string configFile;
+    string configFile;              // long options, default ~/.ssh-cron
     if (not d_arg.option(&configFile, 'c'))
     {
         configFile = User().homedir() + s_defaultConfigFile;
-        if (access(configFile.c_str(), R_OK) != 0)
+        if (not FileSystem{ configFile }.exists() )
             configFile.clear();
     }
     if (not configFile.empty())
