@@ -1,5 +1,7 @@
 #include "options.ih"
 
+    // by setsyslog.cc
+
 Facility Options::syslogFacility() const
 {
     Facility facility;
@@ -9,8 +11,7 @@ Facility Options::syslogFacility() const
         facility = s_defaultSyslogFacility;
     else
     {
-        LinearMap<string, Facility>::const_iterator 
-            iter = s_syslogFacilities.find(option);
+        FacilityMap::const_iterator iter = s_syslogFacilities.find(option);
     
         if (iter == s_syslogFacilities.end())
             fmsg << "syslog facility " << option << " not supported" << endl;
