@@ -1,5 +1,7 @@
 #include "options.ih"
 
+    // by setsyslog.cc
+
 Priority Options::syslogPriority() const
 {
     Priority priority;
@@ -9,8 +11,7 @@ Priority Options::syslogPriority() const
         priority = s_defaultSyslogPriority;
     else
     {
-        LinearMap<std::string, Priority>::const_iterator 
-            iter = s_syslogPriorities.find(option);
+        PriorityMap::const_iterator iter = s_syslogPriorities.find(option);
     
         if (iter == s_syslogPriorities.end())
             fmsg << "syslog priority " << option << " not supported" << endl;
